#!/usr/bin/env python

"""
PyQt-compatible resources for use with WebStack.

Copyright (C) 2005 Paul Boddie <paul@boddie.org.uk>

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
"""

import XSLForms.Prepare
import XSLForms.Resources.Common
import XSLForms.Resources.WebResources
import os
import libxml2dom

class XSLFormsResource(XSLForms.Resources.WebResources.XSLFormsResource):

    """
    An XSLForms resource supporting PyQt-compatible Web applications for use
    with WebStack.
    """

    widget_resources = {}

    def get_document(self, document_identifier):
        return libxml2dom.parse(self.prepare_document(document_identifier))

    def prepare_widget(self, design_identifier, widget_identifier, parent=None):
        design_path = self.prepare_design(design_identifier)
        fragment_name, widget_name = self.widget_resources[widget_identifier]
        fragment_path = os.path.abspath(os.path.join(self.resource_dir, fragment_name))
        XSLForms.Prepare.ensure_qt_fragment(design_path, fragment_path, widget_name)
        # NOTE: Implement the equivalent here!
        return qtui.QWidgetFactory.create(fragment_path, None, parent)

    def populate_list(self, field, elements):
        # NOTE: Support this!
        current_text = field.currentText()
        while field.count() > 0:
            field.removeItem(0)
        item = 0
        set = 0
        for element in elements:
            text = element.getAttribute("value")
            field.insertItem(text)
            if text == current_text:
                field.setCurrentItem(item)
                set = 1
            item += 1
        if not set:
            field.setCurrentItem(0)

    def reset_collection(self, field):
        # NOTE: Support this!
        layout = field.layout()
        for child in field.children():
            if child is not layout:
                layout.remove(child)
                child.deleteLater()

class Factory:

    "A widget factory helper class."

    def __init__(self, ui_filename):
        self.ui_filename = ui_filename
        self.ui_doc = libxml2dom.parse(ui_filename)

    def connect(self, widget, obj):
        pass

    def find_widgets(self, widget, name):
        # NOTE: Support this!
        widgets = []
        found = widget.child(name)
        if found:
            widgets.append(found)
        for child in widget.children():
            widgets += self.find_widgets(child, name)
        return widgets

# vim: tabstop=4 expandtab shiftwidth=4
